@@ -11,7 +11,7 @@ divisors <-
       return(list(num=1, divs = 1))
       
     
-    numD = .C("numdivs", n = as.integer(n), out = double(length=1))$out
+    numD = .C("numdivs", n = as.integer(n), out = integer(length=1))$out
     divs = .C("divisors", n = as.integer(n), ln = as.integer(numD),
       out = double(length = 1),
       divs = double(length = numD))
@@ -30,3 +30,21 @@ divisors <-
     
     return(list(num = numD, divs = divs$divs))
   }
+
+
+numdivs <-
+  # just number of divisors, vectorized in C
+  function(n){
+    if(length(n) == 1L){
+      numD = .C(name="numdivs", n = as.integer(n),
+        out = integer(length=1))$out
+    }
+    else{
+      numD = .C(name = "vecnumdivs", n = as.integer(n),
+        na = as.integer(length(n)),
+        out = vector("integer", length=length(n)))$out
+    }
+
+    #still checking for double number in R.
+    numD = ifelse(floor(sqrt(n)) == sqrt(n), numD - 1, numD)
+    numD}
